@@ -9,9 +9,9 @@
 #include <QUrl>
 #include <QVariant>
 
-#include <KIOFileWidgets/KDirSortFilterProxyModel>
-#include <KIOWidgets/KDirModel>
-class DirLister;
+#include <KDirModel>
+#include <KDirSortFilterProxyModel>
+class KDirLister;
 
 class DirModel : public KDirSortFilterProxyModel
 {
@@ -74,7 +74,7 @@ Q_SIGNALS:
 
 private:
     KDirModel m_dirModel;
-    DirLister *m_lister;
+    KDirLister *m_lister;
 
     QString m_lastError;
 };
