@@ -65,6 +65,7 @@ public:
     void acquireStreamingInput(bool acquire);
 
     Stream startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode);
+    Stream startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode);
     Stream startStreamingWindow(const QMap<int, QVariant> &win, Screencasting::CursorMode mode);
     Stream startStreamingWorkspace(Screencasting::CursorMode mode);
     Stream startStreamingVirtualOutput(const QString &name, const QSize &size, Screencasting::CursorMode mode);
@@ -73,7 +74,7 @@ public:
     void requestPointerButtonPress(quint32 linuxButton);
     void requestPointerButtonRelease(quint32 linuxButton);
     void requestPointerMotion(const QSizeF &delta);
-    void requestPointerMotionAbsolute(const QPointF &pos);
+    void requestPointerMotionAbsolute(uint stream, const QPointF &pos);
     void requestPointerAxis(qreal x, qreal y);
     void requestPointerAxisDiscrete(Qt::Orientation axis, qreal delta);
     void requestKeyboardKeycode(int keycode, bool state);
@@ -101,8 +102,6 @@ private:
     QDateTime m_lastFrameTime;
     QVector<Stream> m_streams;
 
-    QPoint m_streamedScreenPosition;
-
     QMap<quint32, WaylandOutput> m_outputMap;
 
     KWayland::Client::FakeInput *m_fakeInput = nullptr;
